@@ -85,7 +85,7 @@ if __name__ == "__main__":
         BRANCH = os.getenv("GITHUB_HEAD_REF")
 
     COMMIT = os.getenv("GITHUB_SHA")
-    TRANSFORM_CONFIG_DIR = os.getenv("TRANSFORM_CONFIG_DIR").rstrip()
-    TRANSFORM_API_KEY = os.environ["TRANSFORM_API_KEY"].rstrip()  # fail if TRANSFORM_API_KEY not present
+    TRANSFORM_CONFIG_DIR = os.getenv("TRANSFORM_CONFIG_DIR").lstrip().rstrip()
+    TRANSFORM_API_KEY = os.environ["TRANSFORM_API_KEY"].lstrip().rstrip()  # fail if TRANSFORM_API_KEY not present
 
     upload_configs(mode, TRANSFORM_API_KEY, REPO, BRANCH, COMMIT, TRANSFORM_CONFIG_DIR)
